==> capnp-ocaml-2.1.1.tar.gz: capnp-ocaml-2.1.1/src/tests/testMisc.ml <==
(******************************************************************************
 * capnp-ocaml
 *
 * Copyright (c) 2013-2014, Paul Pelzl
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 ******************************************************************************)

open OUnit2

let encode_signed_suite =
  let open Capnp.Runtime.Util in
  let t0 ctx = assert_equal (encode_signed 17 0) 0 in
  let t1 ctx = assert_equal (encode_signed 17 0xffff) 0xffff in
  let t2 ctx = assert_equal (encode_signed 17 (-0x10000)) 0x10000 in
  let t3 ctx = assert_equal (encode_signed 17 0x1234) 0x1234 in
  let t4 ctx = assert_equal (encode_signed 17 (-0x1234)) 0x1edcc in
  "encode_signed" >::: [
    "zero" >:: t0;
    "max" >:: t1;
    "min" >:: t2;
    "random positive" >:: t3;
    "random negative" >:: t4;
  ]

let decode_signed_suite =
  let open Capnp.Runtime.Util in
  let t0 ctx = assert_equal (decode_signed 17 0) 0 in
  let t1 ctx = assert_equal (decode_signed 17 0xffff) 0xffff in
  let t2 ctx = assert_equal (decode_signed 17 0x10000) (-0x10000) in
  let t3 ctx = assert_equal (decode_signed 17 0x1234) 0x1234 in
  let t4 ctx = assert_equal (decode_signed 17 0x1edcc) (-0x1234) in
  "decode_signed" >::: [
    "zero" >:: t0;
    "max" >:: t1;
    "min" >:: t2;
    "random positive" >:: t3;
    "random negative" >:: t4;
  ]

let () = run_test_tt_main encode_signed_suite
let () = run_test_tt_main decode_signed_suite

==> capnp-ocaml-3.1.0.tar.gz: capnp-ocaml-3.1.0/src/tests/testMisc.ml <==
(******************************************************************************
 * capnp-ocaml
 *
 * Copyright (c) 2013-2014, Paul Pelzl
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 ******************************************************************************)

open OUnit2

module TestCycles = TestCycles.Make(Capnp.BytesMessage)

let encode_signed_suite =
  let open Capnp.Runtime.Util in
  let t0 _ctx = assert_equal (encode_signed 17 0) 0 in
  let t1 _ctx = assert_equal (encode_signed 17 0xffff) 0xffff in
  let t2 _ctx = assert_equal (encode_signed 17 (-0x10000)) 0x10000 in
  let t3 _ctx = assert_equal (encode_signed 17 0x1234) 0x1234 in
  let t4 _ctx = assert_equal (encode_signed 17 (-0x1234)) 0x1edcc in
  "encode_signed" >::: [
    "zero" >:: t0;
    "max" >:: t1;
    "min" >:: t2;
    "random positive" >:: t3;
    "random negative" >:: t4;
  ]

let decode_signed_suite =
  let open Capnp.Runtime.Util in
  let t0 _ctx = assert_equal (decode_signed 17 0) 0 in
  let t1 _ctx = assert_equal (decode_signed 17 0xffff) 0xffff in
  let t2 _ctx = assert_equal (decode_signed 17 0x10000) (-0x10000) in
  let t3 _ctx = assert_equal (decode_signed 17 0x1234) 0x1234 in
  let t4 _ctx = assert_equal (decode_signed 17 0x1edcc) (-0x1234) in
  "decode_signed" >::: [
    "zero" >:: t0;
    "max" >:: t1;
    "min" >:: t2;
    "random positive" >:: t3;
    "random negative" >:: t4;
  ]

let cycle_suite =
  let open TestCycles in
  let t0 _ctx =
    let root = Builder.Foo.init_root () in
    let bar = Builder.Foo.bar_init root in
    let foo2 = Builder.Bar.foo_init bar in
    Builder.Foo.x_set foo2 42l;
    let root = Builder.Foo.to_reader root in
    let bar = Reader.Foo.bar_get root in
    let foo = Reader.Bar.foo_get bar in
    OUnit2.assert_equal (Reader.Foo.x_get foo) (Builder.Foo.x_get foo2);
  in
  "cycles" >::: [
    "simple" >:: t0;
  ]
